Browse groups - Tildes
Description: Tildes: a non-profit community site

#

# Browse groups

1. ~anime - Posts about anime and the related media/genres including TV shows, manga, movies, and games.
   Approx. daily activity: 2 topics, 52 comments
2. ~arts - Articles and discussions about the arts - theatre, drawing, painting, photography, poetry, etc.
   Approx. daily activity: 1 topic, 5 comments
3. ~books - Discussion, news and articles related to books (fiction or non-fiction).
   Approx. daily activity: 2 topics, 53 comments
4. ~comp - Topics focused on the more technical side of computers, things of interest to programmers, sysadmins, etc.
   Approx. daily activity: 3 topics, 41 comments
5. ~creative - Arts, crafts, and other DIY-ish things.
   Approx. daily activity: 2 topics, 44 comments
6. ~design - Topics related to design, both physical (e.g. fashion, architecture, products) and non-physical (e.g. logos, web design, advertising)
   Approx. daily activity: 1 topic, 20 comments
7. ~enviro - Topics related to the environment - conservation, recycling, alternate energy, etc.
   Approx. daily activity: 2 topics, 13 comments
8. ~finance - Topics related to business, economics, personal finance, investing, the stock market, and so on.
   Approx. daily activity: 2 topics, 19 comments
9. ~food - Topics related to food (and drinks!).
   Approx. daily activity: 4 topics, 86 comments
10. ~games - News and discussion about games of all types - video games, tabletop games, board games, etc.
    Approx. daily activity: 11 topics, 260 comments

1. ~games.game_design - Articles and discussion about game design including mechanics, environments, audio, and AI.
   Approx. daily activity: 1 topic, 20 comments
2. ~games.tabletop - Topics about tabletop games: board games (both modern and classical), role-playing games, card games, etc.
   Approx. daily activity: 2 topics, 27 comments

11. ~health - A place for discussions concerning health - diets, fitness, etc.
    Approx. daily activity: 2 topics, 49 comments
12. ~hobbies - Discussing hobbies - what are you into?
    Approx. daily activity: 5 topics, 150 comments
13. ~humanities - Topics and discussion related to the humanities - history, philosophy, language, and so on.
    Approx. daily activity: 2 topics, 22 comments
14. ~lgbt - This group includes discussions and news regarding LGBT-related topics. The umbrella term "LGBT" includes all minority sexualities and gender identities. Everybody is welcome to participate.
    Approx. daily activity: 2 topics, 9 comments
15. ~life - Topics related to our personal (and professional) lives - work, school, families, relationships, parenting, etc.
    Approx. daily activity: 3 topics, 50 comments
16. ~misc - Topics that don't fit anywhere else.
    Approx. daily activity: 2 topics, 18 comments
17. ~movies - Movie-related news, trailers, discussion, etc.
    Approx. daily activity: 3 topics, 14 comments
18. ~music - Music and related topics. Share songs and music videos, ask for recommendations, post articles, reviews, and more.
    Approx. daily activity: 5 topics, 66 comments
19. ~news - All the world's current events, including politics as well as analysis or opinion pieces. Please tag topics with the name of the relevant country or countries.
    Approx. daily activity: 4 topics, 42 comments
20. ~science - Everything science-related: discoveries, studies, articles, discussions, and questions. Topics related to any scientific discipline are welcome.
    Approx. daily activity: 2 topics, 6 comments
21. ~space - Topics about the universe, space exploration, and related subjects such as rocketry and satellites.
    Approx. daily activity: 1 topic, 2 comments
22. ~sports - Sports news, discussions, etc.
    Approx. daily activity: 4 topics, 35 comments
23. ~talk - Open-ended discussions with fellow Tildes users, casual or serious.
    Approx. daily activity: 4 topics, 289 comments
24. ~tech - Technology news and discussions, intended for a general audience. Posts requiring deep technical knowledge should go in more-specific groups.
    Approx. daily activity: 9 topics, 394 comments
25. ~test - For testing features, markdown, trying to break the site, etc. DON'T POST ANYTHING IMPORTANT IN HERE, IT MAY BE WIPED AT ANY TIME.
    Approx. daily activity: 1 topic, 11 comments
26. ~tildes - Meta discussion about Tildes itself, including questions, suggestions, and bug reports.
    Approx. daily activity: 4 topics, 274 comments

1. ~tildes.official - Official Tildes announcements, updates, and daily discussions (admin posts only).
   Approx. daily activity: 1 topic, 30 comments

27. ~tv - Television news, trailers, discussion, etc.
    Approx. daily activity: 2 topics, 45 comments

Activity numbers are based on posts in the group over the last week, and only update once per day, shortly after 00:00 UTC.